#!/bin/sh

#####################  Start: User Defined Section  ###########################

# ------------------------------ BACKUP_SET --------------------------------- #
# The name of the backup set that you want to run                             #
# If backup set name is not in English, please use BackupSetID                #
# e.g. SET BACKUP_SET="1119083740107"                                         #
#  or  SET BACKUP_SET="FileBackupSet-1"                                       #
#  For ACB, the backup set name is always "Backup Set" .                      #
# --------------------------------------------------------------------------- #
BACKUP_SET="Backup Set"


# ------------------------------ BACKUP_TYPE -------------------------------- #
# Set backup type. You don't need to change this if you are backing up a      #
# file backup set.                                                            #
# Options available: FILE/DATABASE/DIFFERENTIAL/LOG                           #
# e.g. SET BACKUP_TYPE="FILE"          for file backup                        #
#  or  SET BACKUP_TYPE="DATABASE"      for Full database backup               #
#  or  SET BACKUP_TYPE="DIFFERENTIAL"  for Differential database backup       #
#  or  SET BACKUP_TYPE="LOG"           for Log database backup                #
# --------------------------------------------------------------------------- #
BACKUP_TYPE="FILE"


# ----------------------------- SETTING_HOME -------------------------------- #
# Directory to your OBM setting home. Default to ~/.acb when not set.         #
# e.g. SETTING_HOME=~/.acb                                                    #
# --------------------------------------------------------------------------- #
SETTING_HOME=~/.acb


# ------------------------------- DELTA_HOME -------------------------------- #
# Set In-File Delta mode.                                                     #
# Options available: Incremental/Differential/Full (I/D/F)                    #
# e.g. SET DELTA_MODE="I"   for Incremental In-file delta backup              #
#  or  SET DELTA_MODE="D"   for Differential In-file delta backup             #
#  or  SET DELTA_MODE="F"   for Full File backup                              #
#  or  SET DELTA_MODE=""    for using backup set in-file delta setting        #
# --------------------------------------------------------------------------- #
DELTA_MODE=""


# ------------------------------- DEBUG_MODE -------------------------------- #
# Set the debug mode. Options available: [ DEBUG | NO-DEBUG  ]                #
# e.g. DEBUG_MODE="NO-DEBUG"                                                  #
# As of v5.2.2.5, debug mode is not available in ACB. This option is here     #
# for future references only.                                                 #
# --------------------------------------------------------------------------- #
DEBUG_MODE="NO-DEBUG"



######################  END: User Defined Section  ############################

###############################################################################
#           S C R I P T                         U S A G E                     #
###############################################################################

if [ -z "$BACKUP_SET" ]; then
    echo "Usage: RunBackupSet.sh "
    exit 0;
fi

###############################################################################
#      R E T R I E V E            A P P _ H O M E           P A T H           #
###############################################################################

cd `dirname "$0"`
APP_BIN=`pwd`
APP_HOME=`dirname "$APP_BIN"`

###############################################################################
#      R E T R I E V E           J A V A _ H O M E           P A T H          #
###############################################################################

JAVA_HOME=/System/Library/Frameworks/JavaVM.framework/Home

if [ ! -x "$APP_HOME/jvm" ];
then
   echo "$APP_HOME/jvm does not exist! Creating a symbolic link from ${APP_HOME}/jvm to ${JAVA_HOME}"
   ln -sf "${JAVA_HOME}" "${APP_HOME}/jvm"
fi

###############################################################################
#                  J A V A                 E X E C U T I O N                  #
###############################################################################

cd "$APP_HOME"

LIB_HOME=./bin
JAVA_OPTS="-Xmx256m -client -Djava.library.path=$APP_HOME/bin"
CLASSPATH=$LIB_HOME:$LIB_HOME/acb.jar:$LIB_HOME/acb-lib.jar
MAIN_CLASS=RunBackupSet

echo "Using APP_HOME:    : ${APP_HOME}"
echo "Using BACKUP_SET   : ${BACKUP_SET}"
echo "Using BACKUP_TYPE  : ${BACKUP_TYPE}"
echo "Using SETTING_HOME : ${SETTING_HOME}"
echo "Using DELTA_MODE   : ${DELTA_MODE}"
echo "Using DEBUG_MODE   : ${DEBUG_MODE}"
echo "Using MAIN_CLASS   : ${MAIN_CLASS}"

"${APP_HOME}/jvm/bin/java" $JAVA_OPTS -cp "${CLASSPATH}" "${MAIN_CLASS}" "${APP_HOME}" "${BACKUP_SET}" "${BACKUP_TYPE}" "${SETTING_HOME}" "${DELTA_MODE}" "${DEBUG_MODE}"

exit 0
